[ALDI]
ids = [6603122027]
first_name = Alexander
last_name = Dierlamm
keywords = ["Semiconductor sensors"]
scopus_whitelist = [60102538, 60027314]
scopus_blacklist = []

[MABA]
ids = [35519411500]
first_name = Matthias
last_name = Balzer
keywords = ["Programmable electronics"]
scopus_whitelist = [60027314, 60102538, 110986687]
scopus_blacklist = []

[OLSA]
ids = [22986354000]
first_name = Oliver
last_name = Sander
keywords = ["Programmable electronics"]
scopus_whitelist = [60019778, 60102538, 110028837, 60027314, 60016653]
scopus_blacklist = []

[LORO]
ids = [56473442500]
first_name = Lorenzo
last_name = Rota
keywords = ["Programmable electronics"]
scopus_whitelist = [60102538, 60012306, 60027314]
scopus_blacklist = []

[SUCH]
ids = [15076530600]
first_name = Suren
last_name = Chilingaryan
keywords = ["Real-time data processing"]
scopus_whitelist = [60070862, 60102538, 60027314]
scopus_blacklist = []

[MAVO]
ids = [35303862100]
first_name = Matthias
last_name = Vogelgesang
keywords = ["Real-time data processing"]
scopus_whitelist = [60102538, 114062636, 60027314, 60028453]
scopus_blacklist = []